package org.libre.ejb;

import java.util.ArrayList;
import java.util.List;
import javax.ejb.LocalBean;
import javax.ejb.Stateless;
import javax.ejb.TransactionManagement;
import javax.ejb.TransactionManagementType;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.NoResultException;
import javax.persistence.Persistence;
import javax.transaction.SystemException;
import javax.transaction.UserTransaction;
import org.libre.entities.Person;
import org.libre.utilities.Transactions;

/**
 * Session Bean implementation class PersonBean
 */
@Stateless
@LocalBean
@TransactionManagement(value = TransactionManagementType.BEAN) 
public class PersonBean implements PersonBeanRemote, PersonBeanLocal {
	private EntityManagerFactory emf = Persistence.createEntityManagerFactory("libre-jpa");
	
    /**
     * Default constructor. 
     */
    public PersonBean() {
    }

    @Override
    public Person createPersonInsideYourOwnTransaction(String fname, String lname) {
	   	Person p = new Person();
    	p.setFname(fname);
    	p.setLname(lname);
    	
    	UserTransaction utx = Transactions.getTransactionsInstance().getJtaTransaction();
    	
    	EntityManager em = emf.createEntityManager();
    	try {
    		try {
	    		return (Person) em.createNamedQuery("Person.findByNames")
	    			.setParameter("fname", fname)
	    			.setParameter("lname", lname)
	    			.getSingleResult();
    		} catch (NoResultException chkPersonExc) {
    		}
    		
    		utx.begin();
    		em.joinTransaction();
	    	em.persist(p);
	    	utx.commit();
	    	
    		return p;
    	} catch (Exception x) {
    		try {
    			utx.rollback();
    		} catch (SystemException z) {
    			
    		}
    		x.printStackTrace();
    	} finally {
    		em.close();
    	}
    	
    	return null;
    }
    
    @Override
    public List<Person> getAllPersons() {
    	
    	List<Person> persons = new ArrayList<Person>();
    	
    	EntityManager em = emf.createEntityManager();
    	for (Object op : em.createNamedQuery("Person.findAll").getResultList()) {
    		persons.add((Person) op);
    	}
    	em.close();
    	
    	return persons;
    }

}
