package org.libre.ejb;

import java.sql.Timestamp;
import java.util.Calendar;
import java.util.Date;
import java.util.GregorianCalendar;

import javax.ejb.Stateless;
import javax.persistence.EntityManager;
import javax.persistence.EntityManagerFactory;
import javax.persistence.NoResultException;
import javax.persistence.Persistence;
import javax.transaction.SystemException;
import javax.transaction.UserTransaction;

import org.libre.entities.User;
import org.libre.utilities.Transactions;

/**
 * Session Bean implementation class UserBean
 */
@Stateless
public class UserBean implements UserBeanRemote, UserBeanLocal {

	EntityManagerFactory emf = Persistence.createEntityManagerFactory("libre-jpa");
	
    /**
     * Default constructor. 
     */
    public UserBean() {
    }

	@Override
	public User getUser(String login) {
		EntityManager em = emf.createEntityManager();
		
		try {
			return (User) em.createNamedQuery("User.findByLogin")
				.setParameter("systemUserName", login)
				.getSingleResult();
		} catch (NoResultException e) {
			return null;
		} finally {
			em.close();
		}
	}

	@Override
	public boolean createNewUserInsideYourOwnTransactions(String systemUserName,
			String systemUserPassword, Date startValidDate, Date endValidDate,
			String userFirstName, String userLastName) {
		
		EntityManager em = emf.createEntityManager();
		
		User u = new User();
		u.setSystemName(systemUserName);
		u.setSystemPassword(systemUserPassword);
		u.setUserFirstName(userFirstName);
		u.setUserLastName(userLastName);
		Calendar gc = GregorianCalendar.getInstance();
		gc.setTime(startValidDate);
		u.setSystemValidStartDate(new Timestamp(gc.getTimeInMillis()/1000));
		gc.setTime(endValidDate);
		u.setSystemValidEndDate(new Timestamp(gc.getTimeInMillis()/1000));
		
		try {
			em.createNamedQuery("User.findByUser")
				.setParameter("systemUserName", systemUserName)
				.getSingleResult();
		} catch (NoResultException e) {
			return false;
		} finally {
			em.close();
		}
		
		UserTransaction utx = Transactions.getTransactionsInstance().getJtaTransaction();
		try {
			utx.begin();
			em.joinTransaction();
			em.persist(u);
			utx.commit();
			
			return true;
		} catch (Exception e) {
			try {
				utx.rollback();
			} catch (SystemException tex) {
			}
			e.printStackTrace();
		} finally {
			em.close();
		}
		
		return false;
	}
	
	public User canYouGetIntoSystem(String login, String password) {
		User u = getUser(login);
		
		Calendar gc = GregorianCalendar.getInstance();
		gc.setTimeInMillis(System.currentTimeMillis());
		if (u != null &&
				u.getSystemValidStartDate().before(gc.getTime()) 
				&& u.getSystemValidEndDate().after(gc.getTime())
				&& u.getSystemPassword().equals(password)) {
			
			return u;
		}
		
		return null;
	}
		
}
