package org.libre.entities;

import java.io.Serializable;
import javax.persistence.*;
import java.util.Set;


/**
 * The persistent class for the person database table.
 * 
 */
@Entity
@Table(name="person", catalog="libre", schema="data")
@NamedQueries
(
	{
		@NamedQuery(name="Person.findAll", query="SELECT p FROM Person p"),
		@NamedQuery(name="Person.findByIdx", query="SELECT p FROM Person p WHERE p.idx= :idx"),
		@NamedQuery(name="Person.findByNames", query="SELECT p FROM Person p WHERE p.fname= :fname AND p.lname= :lname")
	}
)
public class Person implements Serializable {
	private static final long serialVersionUID = 1L;

	@Id
	@SequenceGenerator(name="PERSON_IDX_GENERATOR", sequenceName="DATA.PERSON_IDX_SEQ")
	@GeneratedValue(strategy=GenerationType.SEQUENCE, generator="PERSON_IDX_GENERATOR")
	private Integer idx;

	@Column(name="fname")
	private String fname;

	@Column(name="lname")
	private String lname;

	//bi-directional many-to-one association to Author
	@OneToMany(mappedBy="person")
	private Set<Author> authors;

    public Person() {
    }

	public Integer getIdx() {
		return this.idx;
	}

	public void setIdx(Integer idx) {
		this.idx = idx;
	}

	public String getFname() {
		return this.fname;
	}

	public void setFname(String fname) {
		this.fname = fname;
	}

	public String getLname() {
		return this.lname;
	}

	public void setLname(String lname) {
		this.lname = lname;
	}

	public Set<Author> getAuthors() {
		return this.authors;
	}

	public void setAuthors(Set<Author> authors) {
		this.authors = authors;
	}
	
}