package org.libre.web.base;

import java.util.Date;
import java.util.Map;

import javax.annotation.PostConstruct;
import javax.annotation.PreDestroy;
import javax.faces.context.FacesContext;
import org.libre.web.base.exceptions.BaseActionException;
import org.libre.web.base.exceptions.NotCurrentUserFoundException;
import org.libre.web.base.utils.GlobalSettings;

public abstract class ABaseActionBean implements IBaseActionBean {

	protected abstract void afterStart();
	protected abstract void beforeEnd();

	private static final String ACTION_SESSION_FAIL = "sessionFial";
	private static final String FAIL_PAGE_URL = "/libre/pages/login.xhtml";
	private static final String FAIL_PAGE_ERROR_URL = "/libre/pages/error.xhtml";
	
	private Map<String, Object> user 	= null;
	
	private String systemName 			= "";
	private String userFirstName 		= "";
	private String userLastName 		= "";
	private Date systemValidStartDate	= null;
	private Date systemValidEndDate		= null;
	
	@PostConstruct
	protected void start() throws Exception {
		try {
			this.user = new GlobalSettings().getCurrentuser();
			
			this.setSystemName((String) (getCurrentUser().get(GlobalSettings.CURRENT_USER_SYSTEM_NAME)));
			this.setUserFirstName((String) (getCurrentUser().get(GlobalSettings.CURRENT_USER_FIRST_NAME)));
			this.setUserLastName((String) (getCurrentUser().get(GlobalSettings.CURRENT_USER_LAST_NAME)));
			this.setSystemValidStartDate((Date) (getCurrentUser().get(GlobalSettings.CURRENT_USER_SYSTEM_VALID_START_DATE)));
			this.setSystemValidEndDate((Date) (getCurrentUser().get(GlobalSettings.CURRENT_USER_SYSTEM_VALID_END_DATE)));
			
			afterStart();
		} catch (NotCurrentUserFoundException e) {
			FacesContext.getCurrentInstance().getExternalContext().redirect(getNextPageUrl(e));
		}
	}
	
	public Map<String, Object> getCurrentUser() {
		return this.user;
	}
	
	@PreDestroy
	public void end() {
		beforeEnd();
	}
	
	@Override
	public String getNextPageUrl(BaseActionException e) { 
		if (e instanceof NotCurrentUserFoundException)
			return ABaseActionBean.FAIL_PAGE_URL;
		else
			return ABaseActionBean.FAIL_PAGE_ERROR_URL;
	}

	@Override
	public String getAction() {
		return ABaseActionBean.ACTION_SESSION_FAIL;
	}

	@Override
	public String getNextPageUrl() {
		return ABaseActionBean.FAIL_PAGE_URL;
	}
	public String getSystemName() {
		return systemName;
	}
	public void setSystemName(String systemName) {
		this.systemName = systemName;
	}
	public String getUserFirstName() {
		return userFirstName;
	}
	public void setUserFirstName(String userFirstName) {
		this.userFirstName = userFirstName;
	}
	public String getUserLastName() {
		return userLastName;
	}
	public void setUserLastName(String userLastName) {
		this.userLastName = userLastName;
	}
	public Date getSystemValidStartDate() {
		return systemValidStartDate;
	}
	public void setSystemValidStartDate(Date systemValidStartDate) {
		this.systemValidStartDate = systemValidStartDate;
	}
	public Date getSystemValidEndDate() {
		return systemValidEndDate;
	}
	public void setSystemValidEndDate(Date systemValidEndDate) {
		this.systemValidEndDate = systemValidEndDate;
	}
	
	
}