package org.libre.web.base.utils;

import java.util.Date;
import java.util.HashMap;
import java.util.Map;

import javax.faces.context.FacesContext;
import javax.servlet.http.HttpServletRequest;

import org.libre.web.base.exceptions.DuplicateSessionException;
import org.libre.web.base.exceptions.NotCurrentUserFoundException;
import org.libre.web.mbeans.SystemBean;

public class GlobalSettings {
	
	private HttpServletRequest request = null;
	
	// Current user settings
	public static final String CURRENT_USER_OBJECT 						= "currentUser";
	public static final String CURRENT_USER_SYSTEM_NAME 				= "currentUserSystemName";
	public static final String CURRENT_USER_SYSTEM_PASSWORD 			= "currentUserSystemPassword";
	public static final String CURRENT_USER_SYSTEM_VALID_START_DATE 	= "currentUserSystemValidStartDate";
	public static final String CURRENT_USER_SYSTEM_VALID_END_DATE 		= "currentUserSystemValidEndDate";
	public static final String CURRENT_USER_FIRST_NAME					= "currentUserFirstName";
	public static final String CURRENT_USER_LAST_NAME					= "currentUserLastName";
	public static final String CURRENT_USER_SESSION_ID					= "currentUserSessionId";
	public static final String SYSTEM_BEAN								= "systemBean";

	public GlobalSettings() {
		this.request = (HttpServletRequest)FacesContext.getCurrentInstance().getExternalContext().getRequest();
	}

	public void setCurrentUser(String systemName, String systemPassword, Date systemValidStart, 
			Date systemValidEnd,String userFirstName, String userLastName) {
		Map<String, Object> user = new HashMap<String, Object>();
		user.put(GlobalSettings.CURRENT_USER_SYSTEM_NAME, systemName);
		user.put(GlobalSettings.CURRENT_USER_SYSTEM_PASSWORD, systemPassword);
		user.put(GlobalSettings.CURRENT_USER_SYSTEM_VALID_START_DATE, systemValidStart);
		user.put(GlobalSettings.CURRENT_USER_SYSTEM_VALID_END_DATE, systemValidEnd);
		user.put(GlobalSettings.CURRENT_USER_FIRST_NAME, userFirstName);
		user.put(GlobalSettings.CURRENT_USER_LAST_NAME, userLastName);
		user.put(GlobalSettings.CURRENT_USER_SESSION_ID, this.request.getSession().getId());
		this.request.getSession().setAttribute(GlobalSettings.CURRENT_USER_OBJECT, user);
	}
	
	public boolean isUserLogged() {
		try {
			getCurrentuser();
		} catch (NotCurrentUserFoundException e) {
			return false;
		} catch (DuplicateSessionException f) {
			return false;
		}
		
		return true;
	}
	
	public Map<String, Object> getCurrentuser()
		throws NotCurrentUserFoundException, DuplicateSessionException {
	
		Map<String, Object> u = (Map<String, Object>) this.request.getSession().getAttribute(GlobalSettings.CURRENT_USER_OBJECT);
		
		if (u == null)
			throw new NotCurrentUserFoundException();
		else if (u != null && !this.request.getSession().getId().equals((String)u.get(GlobalSettings.CURRENT_USER_SESSION_ID)))
			throw new DuplicateSessionException();
		else 
			return u;
	}

}
