--
-- PostgreSQL database dump
--

-- Robert Sternal

SET statement_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = off;
SET check_function_bodies = false;
SET client_min_messages = warning;
SET escape_string_warning = off;

--
-- Name: data; Type: SCHEMA; Schema: -; Owner: libre_adm
--

CREATE SCHEMA data;


ALTER SCHEMA data OWNER TO libre_adm;

--
-- Name: system; Type: SCHEMA; Schema: -; Owner: libre_adm
--

CREATE SCHEMA system;


ALTER SCHEMA system OWNER TO libre_adm;

--
-- Name: plpgsql; Type: PROCEDURAL LANGUAGE; Schema: -; Owner: adm
--

CREATE OR REPLACE PROCEDURAL LANGUAGE plpgsql;


ALTER PROCEDURAL LANGUAGE plpgsql OWNER TO adm;

SET search_path = data, pg_catalog;

SET default_tablespace = '';

SET default_with_oids = false;

--
-- Name: author; Type: TABLE; Schema: data; Owner: libre_adm; Tablespace: 
--

CREATE TABLE author (
    isbn character varying(13) NOT NULL,
    pid integer NOT NULL,
    role character(1) DEFAULT 'A'::bpchar NOT NULL,
    idx integer NOT NULL,
    CONSTRAINT author_role_check CHECK ((role = ANY (ARRAY['A'::bpchar, 'T'::bpchar, 'C'::bpchar, 'G'::bpchar])))
);


ALTER TABLE data.author OWNER TO libre_adm;

--
-- Name: author_idx_seq; Type: SEQUENCE; Schema: data; Owner: libre_adm
--

CREATE SEQUENCE author_idx_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE data.author_idx_seq OWNER TO libre_adm;

--
-- Name: author_idx_seq; Type: SEQUENCE OWNED BY; Schema: data; Owner: libre_adm
--

ALTER SEQUENCE author_idx_seq OWNED BY author.idx;


--
-- Name: author_idx_seq; Type: SEQUENCE SET; Schema: data; Owner: libre_adm
--

SELECT pg_catalog.setval('author_idx_seq', 1, false);


--
-- Name: book; Type: TABLE; Schema: data; Owner: libre_adm; Tablespace: 
--

CREATE TABLE book (
    isbn character varying(13) NOT NULL,
    title character varying(252) NOT NULL,
    editor character varying(64) NOT NULL,
    price numeric(8,2)
);


ALTER TABLE data.book OWNER TO libre_adm;

--
-- Name: person; Type: TABLE; Schema: data; Owner: libre_adm; Tablespace: 
--

CREATE TABLE person (
    idx integer NOT NULL,
    fname character varying(32) NOT NULL,
    lname character varying(64) NOT NULL
);


ALTER TABLE data.person OWNER TO libre_adm;

--
-- Name: person_idx_seq; Type: SEQUENCE; Schema: data; Owner: libre_adm
--

CREATE SEQUENCE person_idx_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE data.person_idx_seq OWNER TO libre_adm;

--
-- Name: person_idx_seq; Type: SEQUENCE OWNED BY; Schema: data; Owner: libre_adm
--

ALTER SEQUENCE person_idx_seq OWNED BY person.idx;


--
-- Name: person_idx_seq; Type: SEQUENCE SET; Schema: data; Owner: libre_adm
--

SELECT pg_catalog.setval('person_idx_seq', 288, true);


SET search_path = system, pg_catalog;

--
-- Name: user; Type: TABLE; Schema: system; Owner: libre_adm; Tablespace: 
--

CREATE TABLE "user" (
    idx integer NOT NULL,
    system_name character varying(32) NOT NULL,
    user_first_name character varying(64) NOT NULL,
    user_last_name character varying(128) NOT NULL,
    system_password character varying(64),
    system_valid_start_date timestamp without time zone NOT NULL,
    system_valid_end_date timestamp without time zone NOT NULL,
    CONSTRAINT user_check CHECK ((system_valid_end_date > system_valid_start_date)),
    CONSTRAINT user_system_valid_start_date_check CHECK ((system_valid_start_date >= now()))
);


ALTER TABLE system."user" OWNER TO libre_adm;

--
-- Name: user_idx_seq; Type: SEQUENCE; Schema: system; Owner: libre_adm
--

CREATE SEQUENCE user_idx_seq
    START WITH 1
    INCREMENT BY 1
    NO MINVALUE
    NO MAXVALUE
    CACHE 1;


ALTER TABLE system.user_idx_seq OWNER TO libre_adm;

--
-- Name: user_idx_seq; Type: SEQUENCE OWNED BY; Schema: system; Owner: libre_adm
--

ALTER SEQUENCE user_idx_seq OWNED BY "user".idx;


--
-- Name: user_idx_seq; Type: SEQUENCE SET; Schema: system; Owner: libre_adm
--

SELECT pg_catalog.setval('user_idx_seq', 11, true);


SET search_path = data, pg_catalog;

--
-- Name: idx; Type: DEFAULT; Schema: data; Owner: libre_adm
--

ALTER TABLE author ALTER COLUMN idx SET DEFAULT nextval('author_idx_seq'::regclass);


--
-- Name: idx; Type: DEFAULT; Schema: data; Owner: libre_adm
--

ALTER TABLE person ALTER COLUMN idx SET DEFAULT nextval('person_idx_seq'::regclass);


SET search_path = system, pg_catalog;

--
-- Name: idx; Type: DEFAULT; Schema: system; Owner: libre_adm
--

ALTER TABLE "user" ALTER COLUMN idx SET DEFAULT nextval('user_idx_seq'::regclass);


SET search_path = data, pg_catalog;

--
-- Data for Name: author; Type: TABLE DATA; Schema: data; Owner: libre_adm
--

COPY author (isbn, pid, role, idx) FROM stdin;
\.


--
-- Data for Name: book; Type: TABLE DATA; Schema: data; Owner: libre_adm
--

COPY book (isbn, title, editor, price) FROM stdin;
\.


--
-- Data for Name: person; Type: TABLE DATA; Schema: data; Owner: libre_adm
--

COPY person (idx, fname, lname) FROM stdin;
10350	Robert	Sternal
10400	Magdalena	Sternal
10500	Agnieszka	Radwańska
10550	Rafał	Nowicki
10600	Jan Krzysztof	Bielecki
10650	Bernard	Potocki
10700	Agnieszka	Kałuzna
10750	bartłómiej	Dykcik
10850	Wojciech	Loba
10900	Maciej	Borkowski
10950	Tadeusz	Mazowiecki
11000	Donald	Tusk
11050	Radosław	Sikorski
11100	Jarosław	kaczyński
11150	Jan	Pospieszalski
11200	Andzrej	Olechowski
11250	Bartłómiej	Lidke
11300	Tomsz	Luch
11350	Jakub	Adamczak
11400	Łukasz	Gejewy
10450	Alicja	Sternal
11500	Walburga	Graś
11550	Leszek	Graś
11600	Jan	Graś
11650	Iwona	Skorlińska
11700	Marek	Skorliński
11750	Katarzyna	Skorlińska
11800	Magdalena	Kinc
11850	Anna	Szymańska
11900	Krzysztof	Szymański
11950	Jędrzej	Szymański
12000	Nataia	Szymańska
12050	Danuta	Sternal
12100	Romulada	Sternal
12150	Artur	Kiliszek
12200	Irena	Sternal
12250	Ilona	Sternal
12300	Kamil	Nowicki
12350	Krzysztof	Nowicki
12400	Patrycja	Tomaszewska
12450	Dawid	Tomaszewski
12500	David	Geary
12550	Cay S.	Horstmann
10800	Robert	Szczepański
12600	Ed	Burnette
12650	Tadeusz	Wrona
12700	Piotr	Galiński
12750	Natasza	Urbańska
12800	Janusz	Józefowicz
12850	Katarzyna	Cichopek
12900	Jakub	Wojewódzki
12950	Piotr	Gąsowski
13000	Alexandra	Jakubowska
13050	Tadeusz	Cymański
13100	Zbigniew	Ziobro
13150	jarosław	Kaczyński
13200	Kubuś	Puchatek
13250	Jacek	Kurski
13300	Andrzej	Wojciechowski
13350	Stanisław	Barański
13400	Stanisław	Gądecki
13450	Marek	Jędraszewski
13500	Stanisław	Dziwisz
13550	Tadeusz	Nycz
13600	Adam	Zimoń
13650	Henryk	Michalik
13700	Władysław	Bartoszewski
13750	Stefan	Niesiołowski
13800	Elżbieta	Jakubiak
13850	Tadeusz	Rydzyk
13900	Jacek	Rostowski
13950	Marek	Belka
14000	Hanna	Gronkeiwicz-Watz
14050	Lech	Wałęsa
14100	Danuta	Wałęsa
14150	Jarosław	Wałęsa
14200	Zdzisław	Boniek
14250	Jan	Tomaszewski
14300	Grzegorz	Lato
14350	jan	Stanisławski
14400	Adam	Boniecki
\.


SET search_path = system, pg_catalog;

--
-- Data for Name: user; Type: TABLE DATA; Schema: system; Owner: libre_adm
--

COPY "user" (idx, system_name, user_first_name, user_last_name, system_password, system_valid_start_date, system_valid_end_date) FROM stdin;
2	Magdalena	Mgdalena	Sternal	opsakl22	2011-10-21 18:00:08.464138	2011-11-12 00:00:00
11	Alicja	Alicja	Sternal	opsakl22	2011-10-30 21:55:00	2011-10-30 22:00:00
1	RSternal	Robert	Sternal	opsakl22	2011-11-02 15:25:00	2011-11-30 18:00:00
\.


SET search_path = data, pg_catalog;

--
-- Name: author_pkey; Type: CONSTRAINT; Schema: data; Owner: libre_adm; Tablespace: 
--

ALTER TABLE ONLY author
    ADD CONSTRAINT author_pkey PRIMARY KEY (idx);


--
-- Name: book_pkey; Type: CONSTRAINT; Schema: data; Owner: libre_adm; Tablespace: 
--

ALTER TABLE ONLY book
    ADD CONSTRAINT book_pkey PRIMARY KEY (isbn);


--
-- Name: person_fname_lname_key; Type: CONSTRAINT; Schema: data; Owner: libre_adm; Tablespace: 
--

ALTER TABLE ONLY person
    ADD CONSTRAINT person_fname_lname_key UNIQUE (fname, lname);


--
-- Name: person_pkey; Type: CONSTRAINT; Schema: data; Owner: libre_adm; Tablespace: 
--

ALTER TABLE ONLY person
    ADD CONSTRAINT person_pkey PRIMARY KEY (idx);


SET search_path = system, pg_catalog;

--
-- Name: user_pkey; Type: CONSTRAINT; Schema: system; Owner: libre_adm; Tablespace: 
--

ALTER TABLE ONLY "user"
    ADD CONSTRAINT user_pkey PRIMARY KEY (system_name);


SET search_path = data, pg_catalog;

--
-- Name: fk_book; Type: FK CONSTRAINT; Schema: data; Owner: libre_adm
--

ALTER TABLE ONLY author
    ADD CONSTRAINT fk_book FOREIGN KEY (isbn) REFERENCES book(isbn);


--
-- Name: fk_person; Type: FK CONSTRAINT; Schema: data; Owner: libre_adm
--

ALTER TABLE ONLY author
    ADD CONSTRAINT fk_person FOREIGN KEY (pid) REFERENCES person(idx);


--
-- Name: public; Type: ACL; Schema: -; Owner: adm
--

REVOKE ALL ON SCHEMA public FROM PUBLIC;
REVOKE ALL ON SCHEMA public FROM adm;
GRANT ALL ON SCHEMA public TO adm;
GRANT ALL ON SCHEMA public TO PUBLIC;


--
-- PostgreSQL database dump complete
--
